#[non_exhaustive]pub enum GrantType {
AuthorizationCode,
RefreshToken,
DeviceCode,
}Available on crate features
client or server only.Expand description
The grant type to use at the token endpoint.
This type can hold an arbitrary string. To build this with a custom value, convert it from a
string with ::from() / .into(). To check for values that are not available as a
documented variant here, use its string representation, obtained through
.as_str().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AuthorizationCode
The authorization code grant type (RFC 6749).
RefreshToken
The refresh token grant type (RFC 6749).
DeviceCode
Available on crate feature
unstable-msc4108 only.The device code grant type (RFC 8628).
Implementations